# FeynAmp

[![PyPI version][pypi image]][pypi link] [![PyPI version][pypi versions]][pypi link]  ![downloads](https://img.shields.io/pypi/dm/feynamp.svg)

[![test][a t image]][a t link]      [![Coverage Status][c t i]][c t l]  [![Codacy Badge](https://app.codacy.com/project/badge/Coverage/b7192679265b441cb534c9dc06d1b350)](https://app.codacy.com/gh/APN-Pucky/feynamp/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_coverage)   [![Codacy Badge](https://app.codacy.com/project/badge/Grade/b7192679265b441cb534c9dc06d1b350)](https://app.codacy.com/gh/APN-Pucky/feynamp/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)


## Related

* Mathematica: FormCalc, FeynCalc
* Julia: https://arxiv.org/pdf/2310.07634.pdf

[pypi image]: https://badge.fury.io/py/feynamp.svg
[pypi link]: https://pypi.org/project/feynamp/
[pypi versions]: https://img.shields.io/pypi/pyversions/feynamp.svg

[a t link]: https://github.com/APN-Pucky/feynamp/actions/workflows/test.yml
[a t image]: https://github.com/APN-Pucky/feynamp/actions/workflows/test.yml/badge.svg

[c t l]: https://coveralls.io/github/APN-Pucky/feynamp?branch=master
[c t i]: https://coveralls.io/repos/github/APN-Pucky/feynamp/badge.svg?branch=master
